@@ -61,7 +61,7 @@ import Data.Function (on)
 import qualified Data.HashMap.Strict as H (toList)
 import Data.List (intersperse, sortBy, elemIndex)
 import Data.Maybe (fromMaybe)
-import Data.Monoid ((<>))
+import Data.Semigroup ((<>))
 import qualified Data.Scientific as S (Scientific, FPFormat(..))
 import Data.Ord (comparing)
 import Data.Text (Text)
